==> download.php?d=bsmyjspace_pack_3.0.0_PACK.zip: updateold.myjspace.php <==
<?php
/**
* @version $Id: install.myjspace.php $
* @version		3.0.0 26/08/2019
* @package		com_myjspace
* @author		Bernard Saulmé
* @copyright	Copyright (C) 2010 - 2019 Bernard Saulmé
* @license		GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
*/

defined('_JEXEC') or die;

// Install check & Migration from older component version

// BSHelperUser API
require_once JPATH_ROOT.'/components/com_myjspace/helpers/user.php';

/*
 * Post install :
 * Migrate BS MyJspace over old BS MyJSpace versions: from 1.2 to <= 2.6.0 (if component already installed)
 */

function mjsp_old_postflight()
{
// Config
	$pparams = JComponentHelper::getParams('com_myjspace');
	$db	= JFactory::getDBO();
	$config = new JConfig();

// Check DBO - Update migration only for DB with mysql & mysqli
	if (!in_array($db->name, array('mysql', 'mysqli'))) {
		echo "Upgrade from old BS MyJspace 1.2 to 2.6.0 doesn't take into account this DB!<br>";
		return;
	}

// Post install
	echo '<div> </div>';

	// --------- If migrate from version <= 1.2 --- and count of pages ----------		

	// Index (modification for previous versions)	
	if (!index_exists($config->db, $config->dbprefix.'myjspace', 'idx_pagename')) {
		$query = "CREATE UNIQUE INDEX `idx_pagename` ON `#__myjspace` (pagename)";
		$db->setQuery($query);
		$db->execute();
	}

	// Columns (modifications for previous versions)
	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'last_update_date')) {
		$query = "ALTER TABLE `#__myjspace` ADD COLUMN `last_update_date` timestamp DEFAULT '0000-00-00 00:00:00'";
		$db->setQuery($query);
		$db->execute();
	}

	// Columns (modifications for previous versions)
	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'create_date')) {
		// varchar(15) => varchar(8) : 2.0.2
		$query = "ALTER TABLE `#__myjspace` ADD COLUMN `create_date` timestamp DEFAULT CURRENT_TIMESTAMP, ADD COLUMN `last_access_date` timestamp, ADD COLUMN `last_access_ip` varchar(8) NOT NULL default '0', ADD COLUMN `hits` BIGINT NOT NULL default 0";
		$db->setQuery($query);
		$retour = $db->execute();

		// If migrated from <= 1.2 set create_date with folder last update date
		if ($retour == 1) { // If add column is ok => so it's just migrate from version <= 1.2 ... so continue migrate :-)
			// Root folder
			$folder = $pparams->get('foldername', 'media/myjsp');
			// Subfolder info
			$projectsListIgnore = array('.', '..', 'index.html', 'index.php');
			$oldfolder = getcwd();
			if (!@chdir(JPATH_SITE.'/'.$folder))
				echo "<br />Acces problem for folder : ".$folder."<br />";		
			echo "<br />Search for page creation date in folder : ".$folder."<br />";
			$handle = @opendir('.');
			$compte = 0;
			while (false !== ($file = @readdir($handle))) {
				if (@is_dir($file) && !in_array($file, $projectsListIgnore)) {
					$date_tmp = date('Y-m-d H:i:s', filemtime($file));
					$query = "UPDATE `#__myjspace` SET `create_date` = '".$date_tmp."' WHERE `pagename` = '".$file."'";
					$db->setQuery($query);
					$db->execute();
					$compte = $compte + 1;
				}
			}
			@closedir($handle);
			@chdir($oldfolder);
			echo "Number of pages found : ".$compte."<br />";
		}
	}

	// ----------- End - If migrate from version <= 1.2 -------------------------

	// ---------------- If migrate from version <= 1.6.8 ------------------------
	// Columns (modifications for previous versions)
	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'publish_up')) {
		$query = "ALTER TABLE `#__myjspace` ADD COLUMN `publish_up` timestamp NOT NULL DEFAULT '0000-00-00 00:00:00'";
		$db->setQuery($query);
		$db->execute();
	}

	// Columns (modifications for previous versions)
	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'publish_down')) {
		$query = "ALTER TABLE `#__myjspace` ADD COLUMN `publish_down` timestamp NOT NULL DEFAULT '0000-00-00 00:00:00'";
		$db->setQuery($query);
		$db->execute();
	}

	// ----------- End - If migrate from version <= 1.6.8 -----------------------

	// ----------- If migrate from version < 1.7.4 -----------------------------
	// Columns (modifications for previous versions)
	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'metakey')) {
		$query = "ALTER TABLE `#__myjspace` ADD COLUMN `metakey` text NOT NULL DEFAULT ''";
		$db->setQuery($query);
		$db->execute();
	}

	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'template')) {
		$query = "ALTER TABLE `#__myjspace` ADD COLUMN `template` varchar(50) NOT NULL DEFAULT ''";
		$db->setQuery($query);
		$db->execute();
	}

	// ----------- End - If migrate from version < 1.7.4 -----------------------

	// ----------- If migrate from version < 1.8.0 - part 2 --------------------

	// Delete old component editor files if any. Just for cleanup
	if (@is_dir(JPATH_SITE.'/components/com_myjspace/editor')) {
		rrmdir(JPATH_SITE.'/components/com_myjspace/editor');
		echo "Removed old editor files<br />";
	}

	// ----------- End - If migrate from version < 1.8.0 - part 2 --------------

	// ----------- If migrate from version < 2.0.0 -----------------------------
	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'userid')) {
		$query = "ALTER TABLE `#__myjspace` ADD COLUMN `userid` INT(11) NOT NULL DEFAULT 0";
		$db->setQuery($query);
		$db->execute();
	}

	$query = "UPDATE `#__myjspace` SET `userid` = `id` WHERE `userid` = 0";
	$db->setQuery($query);
	$db->execute();

	if (!index_exists($config->db, $config->dbprefix.'myjspace', 'idx_userid')) {
		$query = "CREATE INDEX `idx_userid` ON `#__myjspace` (`userid`)";
		$db->setQuery($query);
		$db->execute();
	}

	$query = "ALTER TABLE `#__myjspace` CHANGE `id` `id` INT(10) unsigned NOT NULL AUTO_INCREMENT";
	$db->setQuery($query);
	$db->execute();

	// ----------- End - If migrate from version < 2.0.0 -----------------------

	// ----------- If migrate from version < 2.0.1 -----------------------------
	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'catid')) {
		$query = "ALTER TABLE `#__myjspace` ADD `catid` INT(11) NOT NULL DEFAULT 0";
		$db->setQuery($query);
		$db->execute();
	}

	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'modified_by')) {
		$query = "ALTER TABLE `#__myjspace` ADD `modified_by` INT(10) unsigned NOT NULL DEFAULT 0";
		$db->setQuery($query);
		$db->execute();
	}

	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'access')) {
		$query = "ALTER TABLE `#__myjspace` ADD `access` INT(10) unsigned NOT NULL DEFAULT 0";
		$db->setQuery($query);
		$db->execute();
	}

	if (!index_exists($config->db, $config->dbprefix.'myjspace', 'idx_access')) {
		$query = "CREATE INDEX `idx_access` ON `#__myjspace` (access)";
		$db->setQuery($query);
		$db->execute();
	}

	$query = "UPDATE `#__myjspace` SET `modified_by` = `userid` WHERE `modified_by` = 0";
	$db->setQuery($query);
	$db->execute();

	// ----------- End - If migrate from version < 2.0.1 -----------------------

	// ----------- If migrate from version < 2.0.2 -----------------------------

	// Blockview
	$query = "SHOW COLUMNS FROM `#__myjspace` WHERE `field` = 'blockview'";
	$db->setQuery($query);
	$row = $db->loadAssocList();

	if (isset($row[0]['Type']) && $row[0]['Type'] == 'tinyint(4)') {
		echo "Update Acces Level<br />";

		$query = "ALTER TABLE `#__myjspace` CHANGE `blockview` `blockview` INT(10) unsigned NOT NULL DEFAULT 1";
		$db->setQuery($query);
		$db->execute();

		$query = "UPDATE `#__myjspace` SET `blockview` = 9999 WHERE `blockview` = 0";
		$db->setQuery($query);
		$db->execute();

		$query = "UPDATE `#__myjspace` SET `blockview` = 0 WHERE `blockview` = 1";
		$db->setQuery($query);
		$db->execute();

		$query = "UPDATE `#__myjspace` SET `blockview` = 1 WHERE `blockview` = 9999";
		$db->setQuery($query);
		$db->execute();
	}

	// Last_access_ip
	$query = "SHOW COLUMNS FROM `#__myjspace` WHERE `field` = 'last_access_ip'";
	$db->setQuery($query);
	$row = $db->loadAssocList();

	if (isset($row[0]['Type']) && $row[0]['Type'] != 'varchar(8)') {
		echo "Update last_access_ip column<br />";
		$query = "ALTER TABLE `#__myjspace` CHANGE `last_access_ip` `last_access_ip` varchar(8) NOT NULL DEFAULT '0'";
		$db->setQuery($query);
		$db->execute();
	}

	// Del old files
	@unlink(JPATH_ROOT.'/components/com_myjspace/helpers/edit_plus.php');
	@unlink(JPATH_ROOT.'/components/com_myjspace/assets/util.js');
	@unlink(JPATH_ROOT.'/components/com_myjspace/assets/progress2.gif');

	// ----------- End - If migrate from version < 2.0.2 -----------------------

	// ----------- If migrate from version < 2.0.6 -----------------------------

	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'language')) {
		$query = "ALTER TABLE `#__myjspace` ADD `language` char(7) NOT NULL DEFAULT '*'";
		$db->setQuery($query);
		$db->execute();

		if ($pparams->get('categories_filter', 0) == 1) { // Update if categories used for language for search view (BS MyJspace 2.0.5 only)
			echo "Update pages language<br />";
			$query = "UPDATE `#__myjspace` AS b, `#__categories` AS c SET b.language = c.language WHERE b.catid = c.id AND c.extension = 'com_myjspace' AND c.language != '*'";
			$db->setQuery($query);
			$db->execute();
		}
	}

	// ----------- End - If migrate from version < 2.0.6 -----------------------

	// ----------- If migrate from version < 2.2.0 -----------------------------

	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'title')) {
		$query = "ALTER TABLE `#__myjspace` ADD `title` varchar(100) NOT NULL DEFAULT ''";
		$db->setQuery($query);
		$db->execute();

		// Del old file
		@unlink(JPATH_ROOT.'/administrator/components/com_myjspace/sql/delete.mysql.utf8.sql');

		echo "Set new empty pages title with pagenames<br />";
	}

	// ----------- End - If migrate from version < 2.2.0 -----------------------

	// ----------- If migrate from version <= 2.2.0 ----------------------------

	$query = "UPDATE `#__myjspace` SET `title` = `pagename` WHERE `title` = ''";
	$db->setQuery($query);
	$db->execute();

	// ----------- End - If migrate from version <= 2.2.0 -----------------------

	// ----------- If migrate from version <= 2.3.1 ----------------------------

	// Del old file
	@unlink(JPATH_ROOT.'/administrator/components/com_myjspace/sql/install.mysql.utf8.sql');

	// ----------- End - If migrate from version <= 2.3.1 -----------------------

	// ----------- If migrate from version <= 2.5.5 ----------------------------

	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'userread')) {
		$query = "ALTER TABLE `#__myjspace` ADD COLUMN `userread` varchar(100) NOT NULL DEFAULT ''";
		$db->setQuery($query);
		$db->execute();
	}

	// ----------- END - If migrate from version <= 2.5.5 ----------------------------

	// ----------- If migrate from version <= 2.6.0 ----------------------------

	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'foldername')) {
		$query = "ALTER TABLE `#__myjspace` ADD COLUMN `foldername` varchar(150) NOT NULL DEFAULT 'media/myjsp'";
		$db->setQuery($query);
		$db->execute();

		$query = "UPDATE `#__myjspace` SET `foldername` = ".$db->q(BSHelperUser::getRootFoldername())." WHERE `foldername` = 'myjsp'";		
		$db->setQuery($query);
		$db->execute();
	}
		
	// ----------- END - If migrate from version <= 2.6.0 ----------------------------
}

// ------------------------------- End - Checks -------------------------------

// rmdir with file(s) & sub-dir(s)
function rrmdir($dir = null)
{
	if (@is_dir($dir)) {
		$objects = @scandir($dir);
		foreach ($objects as $object) {
			if ($object != "." && $object != "..") {
				if (@filetype($dir.'/'.$object) == "dir") rrmdir($dir.'/'.$object); else @unlink($dir.'/'.$object);
			}
		}
		reset($objects); 
		if (!(@rmdir($dir)))
			@rename($dir, JPATH_SITE.'/tmp/#garbage'); 
	}
}

function column_exists($base, $table, $column)
{
	$db	= JFactory::getDBO();
	$query = "SELECT COUNT(1) `cnt` FROM `information_schema`.`COLUMNS` WHERE `TABLE_SCHEMA` = ".$db->q($base)." AND `TABLE_NAME` = ".$db->q($table)." AND `COLUMN_NAME` = ".$db->q($column);
	$db->setQuery($query);
	return $db->loadResult();
}

function index_exists($base, $table, $index)
{
	$db	= JFactory::getDBO();
	$query = "SELECT COUNT(1) `cnt` FROM `information_schema`.`STATISTICS` WHERE `TABLE_SCHEMA` = ".$db->q($base)." AND `TABLE_NAME` = ".$db->q($table)." AND `INDEX_NAME` = ".$db->q($index);
	$db->setQuery($query);
	return $db->loadResult();
}

==> download.php?d=bsmyjspace_pack_3.1.1_PACK.zip: updateold.myjspace.php <==
<?php
/**
* @version $Id: updateold.myjspace.php $
* @version		3.1.1 24/06/2020
* @package		com_myjspace
* @author		Bernard Saulmé
* @copyright	Copyright (C) 2010 - 2020 Bernard Saulmé
* @license		GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
*/

defined('_JEXEC') or die;

// Install check & Migration from older component version

// BSHelperUser API
require_once JPATH_ROOT.'/components/com_myjspace/helpers/user.php';

/**
 * Post install :
 * Migrate BS MyJspace over old BS MyJSpace versions: from 1.2 to <= 2.6.0 (if component already installed)
 *
 * @return  void
 */

function mjsp_old_postflight()
{
	// Config
	$pparams = JComponentHelper::getParams('com_myjspace');
	$db	= JFactory::getDBO();
	$config = new JConfig();

	// Check DBO - Update migration only for DB with mysql & mysqli
	if (!in_array($db->name, array('mysql', 'mysqli'))) {
		echo "Upgrade from old BS MyJspace 1.2 to 2.6.0 doesn't take into account this DB!<br>";
		return;
	}

	// Post install
	echo '<div> </div>';

	// --------- If migrate from version <= 1.2 --- and count of pages ----------

	// Index (modification for previous versions)
	if (!index_exists($config->db, $config->dbprefix.'myjspace', 'idx_pagename')) {
		$query = "CREATE UNIQUE INDEX `idx_pagename` ON `#__myjspace` (pagename)";
		$db->setQuery($query);
		$db->execute();
	}

	// Columns (modifications for previous versions)
	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'last_update_date')) {
		$query = "ALTER TABLE `#__myjspace` ADD COLUMN `last_update_date` timestamp DEFAULT '0000-00-00 00:00:00'";
		$db->setQuery($query);
		$db->execute();
	}

	// Columns (modifications for previous versions)
	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'create_date')) {
		// varchar(15) => varchar(8) : 2.0.2
		$query = "ALTER TABLE `#__myjspace` ADD COLUMN `create_date` timestamp DEFAULT CURRENT_TIMESTAMP, ADD COLUMN `last_access_date` timestamp, ADD COLUMN `last_access_ip` varchar(8) NOT NULL default '0', ADD COLUMN `hits` BIGINT NOT NULL default 0";
		$db->setQuery($query);
		$retour = $db->execute();

		// If migrated from <= 1.2 set create_date with folder last update date
		if ($retour == 1) { // If add column is ok => so it's just migrate from version <= 1.2 ... so continue migrate :-)
			// Root folder
			$folder = $pparams->get('foldername', 'media/myjsp');
			// Subfolder info
			$projectsListIgnore = array('.', '..', 'index.html', 'index.php');
			$oldfolder = getcwd();
			if (!@chdir(JPATH_SITE.'/'.$folder))
				echo "<br />Acces problem for folder : ".$folder."<br />";
			echo "<br />Search for page creation date in folder : ".$folder."<br />";
			$handle = @opendir('.');
			$compte = 0;
			while (false !== ($file = @readdir($handle))) {
				if (@is_dir($file) && !in_array($file, $projectsListIgnore)) {
					$date_tmp = date('Y-m-d H:i:s', filemtime($file));
					$query = "UPDATE `#__myjspace` SET `create_date` = '".$date_tmp."' WHERE `pagename` = '".$file."'";
					$db->setQuery($query);
					$db->execute();
					$compte = $compte + 1;
				}
			}
			@closedir($handle);
			@chdir($oldfolder);
			echo "Number of pages found : ".$compte."<br />";
		}
	}

	// ----------- End - If migrate from version <= 1.2 -------------------------

	// ---------------- If migrate from version <= 1.6.8 ------------------------
	// Columns (modifications for previous versions)
	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'publish_up')) {
		$query = "ALTER TABLE `#__myjspace` ADD COLUMN `publish_up` timestamp NOT NULL DEFAULT '0000-00-00 00:00:00'";
		$db->setQuery($query);
		$db->execute();
	}

	// Columns (modifications for previous versions)
	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'publish_down')) {
		$query = "ALTER TABLE `#__myjspace` ADD COLUMN `publish_down` timestamp NOT NULL DEFAULT '0000-00-00 00:00:00'";
		$db->setQuery($query);
		$db->execute();
	}

	// ----------- End - If migrate from version <= 1.6.8 -----------------------

	// ----------- If migrate from version < 1.7.4 -----------------------------
	// Columns (modifications for previous versions)
	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'metakey')) {
		$query = "ALTER TABLE `#__myjspace` ADD COLUMN `metakey` text NOT NULL DEFAULT ''";
		$db->setQuery($query);
		$db->execute();
	}

	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'template')) {
		$query = "ALTER TABLE `#__myjspace` ADD COLUMN `template` varchar(50) NOT NULL DEFAULT ''";
		$db->setQuery($query);
		$db->execute();
	}

	// ----------- End - If migrate from version < 1.7.4 -----------------------

	// ----------- If migrate from version < 1.8.0 - part 2 --------------------

	// Delete old component editor files if any. Just for cleanup
	if (@is_dir(JPATH_SITE.'/components/com_myjspace/editor')) {
		rrmdir(JPATH_SITE.'/components/com_myjspace/editor');
		echo "Removed old editor files<br />";
	}

	// ----------- End - If migrate from version < 1.8.0 - part 2 --------------

	// ----------- If migrate from version < 2.0.0 -----------------------------
	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'userid')) {
		$query = "ALTER TABLE `#__myjspace` ADD COLUMN `userid` INT(11) NOT NULL DEFAULT 0";
		$db->setQuery($query);
		$db->execute();
	}

	$query = "UPDATE `#__myjspace` SET `userid` = `id` WHERE `userid` = 0";
	$db->setQuery($query);
	$db->execute();

	if (!index_exists($config->db, $config->dbprefix.'myjspace', 'idx_userid')) {
		$query = "CREATE INDEX `idx_userid` ON `#__myjspace` (`userid`)";
		$db->setQuery($query);
		$db->execute();
	}

	$query = "ALTER TABLE `#__myjspace` CHANGE `id` `id` INT(10) unsigned NOT NULL AUTO_INCREMENT";
	$db->setQuery($query);
	$db->execute();

	// ----------- End - If migrate from version < 2.0.0 -----------------------

	// ----------- If migrate from version < 2.0.1 -----------------------------
	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'catid')) {
		$query = "ALTER TABLE `#__myjspace` ADD `catid` INT(11) NOT NULL DEFAULT 0";
		$db->setQuery($query);
		$db->execute();
	}

	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'modified_by')) {
		$query = "ALTER TABLE `#__myjspace` ADD `modified_by` INT(10) unsigned NOT NULL DEFAULT 0";
		$db->setQuery($query);
		$db->execute();
	}

	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'access')) {
		$query = "ALTER TABLE `#__myjspace` ADD `access` INT(10) unsigned NOT NULL DEFAULT 0";
		$db->setQuery($query);
		$db->execute();
	}

	if (!index_exists($config->db, $config->dbprefix.'myjspace', 'idx_access')) {
		$query = "CREATE INDEX `idx_access` ON `#__myjspace` (access)";
		$db->setQuery($query);
		$db->execute();
	}

	$query = "UPDATE `#__myjspace` SET `modified_by` = `userid` WHERE `modified_by` = 0";
	$db->setQuery($query);
	$db->execute();

	// ----------- End - If migrate from version < 2.0.1 -----------------------

	// ----------- If migrate from version < 2.0.2 -----------------------------

	// Blockview
	$query = "SHOW COLUMNS FROM `#__myjspace` WHERE `field` = 'blockview'";
	$db->setQuery($query);
	$row = $db->loadAssocList();

	if (isset($row[0]['Type']) && $row[0]['Type'] == 'tinyint(4)') {
		echo "Update Acces Level<br />";

		$query = "ALTER TABLE `#__myjspace` CHANGE `blockview` `blockview` INT(10) unsigned NOT NULL DEFAULT 1";
		$db->setQuery($query);
		$db->execute();

		$query = "UPDATE `#__myjspace` SET `blockview` = 9999 WHERE `blockview` = 0";
		$db->setQuery($query);
		$db->execute();

		$query = "UPDATE `#__myjspace` SET `blockview` = 0 WHERE `blockview` = 1";
		$db->setQuery($query);
		$db->execute();

		$query = "UPDATE `#__myjspace` SET `blockview` = 1 WHERE `blockview` = 9999";
		$db->setQuery($query);
		$db->execute();
	}

	// Last_access_ip
	$query = "SHOW COLUMNS FROM `#__myjspace` WHERE `field` = 'last_access_ip'";
	$db->setQuery($query);
	$row = $db->loadAssocList();

	if (isset($row[0]['Type']) && $row[0]['Type'] != 'varchar(8)') {
		echo "Update last_access_ip column<br />";
		$query = "ALTER TABLE `#__myjspace` CHANGE `last_access_ip` `last_access_ip` varchar(8) NOT NULL DEFAULT '0'";
		$db->setQuery($query);
		$db->execute();
	}

	// Del old files
	@unlink(JPATH_ROOT.'/components/com_myjspace/helpers/edit_plus.php');
	@unlink(JPATH_ROOT.'/components/com_myjspace/assets/util.js');
	@unlink(JPATH_ROOT.'/components/com_myjspace/assets/progress2.gif');

	// ----------- End - If migrate from version < 2.0.2 -----------------------

	// ----------- If migrate from version < 2.0.6 -----------------------------

	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'language')) {
		$query = "ALTER TABLE `#__myjspace` ADD `language` char(7) NOT NULL DEFAULT '*'";
		$db->setQuery($query);
		$db->execute();

		if ($pparams->get('categories_filter', 0) == 1) { // Update if categories used for language for search view (BS MyJspace 2.0.5 only)
			echo "Update pages language<br />";
			$query = "UPDATE `#__myjspace` AS b, `#__categories` AS c SET b.language = c.language WHERE b.catid = c.id AND c.extension = 'com_myjspace' AND c.language != '*'";
			$db->setQuery($query);
			$db->execute();
		}
	}

	// ----------- End - If migrate from version < 2.0.6 -----------------------

	// ----------- If migrate from version < 2.2.0 -----------------------------

	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'title')) {
		$query = "ALTER TABLE `#__myjspace` ADD `title` varchar(100) NOT NULL DEFAULT ''";
		$db->setQuery($query);
		$db->execute();

		// Del old file
		@unlink(JPATH_ROOT.'/administrator/components/com_myjspace/sql/delete.mysql.utf8.sql');

		echo "Set new empty pages title with pagenames<br />";
	}

	// ----------- End - If migrate from version < 2.2.0 -----------------------

	// ----------- If migrate from version <= 2.2.0 ----------------------------

	$query = "UPDATE `#__myjspace` SET `title` = `pagename` WHERE `title` = ''";
	$db->setQuery($query);
	$db->execute();

	// ----------- End - If migrate from version <= 2.2.0 -----------------------

	// ----------- If migrate from version <= 2.3.1 ----------------------------

	// Delete old file
	@unlink(JPATH_ROOT.'/administrator/components/com_myjspace/sql/install.mysql.utf8.sql');

	// ----------- End - If migrate from version <= 2.3.1 -----------------------

	// ----------- If migrate from version <= 2.5.5 ----------------------------

	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'userread')) {
		$query = "ALTER TABLE `#__myjspace` ADD COLUMN `userread` varchar(100) NOT NULL DEFAULT ''";
		$db->setQuery($query);
		$db->execute();
	}

	// ----------- END - If migrate from version <= 2.5.5 ----------------------------

	// ----------- If migrate from version <= 2.6.0 ----------------------------

	if (!column_exists($config->db, $config->dbprefix.'myjspace', 'foldername')) {
		$query = "ALTER TABLE `#__myjspace` ADD COLUMN `foldername` varchar(150) NOT NULL DEFAULT 'media/myjsp'";
		$db->setQuery($query);
		$db->execute();

		$query = "UPDATE `#__myjspace` SET `foldername` = ".$db->q(BSHelperUser::getRootFoldername())." WHERE `foldername` = 'myjsp'";
		$db->setQuery($query);
		$db->execute();
	}

	// ----------- END - If migrate from version <= 2.6.0 ----------------------------
}

// ------------------------------- End - Checks -------------------------------

/**
 * rmdir with file(s) & sub-dir(s)
 *
 * @param   string  $dir  Directory to empty
 *
 * @return  void
 */
function rrmdir($dir = null)
{
	if (@is_dir($dir)) {
		$objects = @scandir($dir);
		foreach ($objects as $object) {
			if ($object != "." && $object != "..") {
				if (@filetype($dir.'/'.$object) == "dir") rrmdir($dir.'/'.$object); else @unlink($dir.'/'.$object);
			}
		}
		reset($objects);
		if (!(@rmdir($dir)))
			@rename($dir, JPATH_SITE.'/tmp/#garbage');
	}
}

/*
 * Check if a column exists for a table
 *
 * @param   string  $base    DB name
 * @param   string  $table   Table name
 * @param   string  $column  Column name
 *
 * @return  integer 0 if not exists, else 1
 */
function column_exists($base, $table, $column)
{
	$db	= JFactory::getDBO();
	$query = "SELECT COUNT(1) `cnt` FROM `information_schema`.`COLUMNS` WHERE `TABLE_SCHEMA` = ".$db->q($base)." AND `TABLE_NAME` = ".$db->q($table)." AND `COLUMN_NAME` = ".$db->q($column);
	$db->setQuery($query);

	return $db->loadResult();
}

/*
 * Check if an index exists for a table
 *
 * @param   string  $base    DB name
 * @param   string  $table   Table name
 * @param   string  $index   Index name
 *
 * @return  integer 0 if not exists, else 1
 */
function index_exists($base, $table, $index)
{
	$db	= JFactory::getDBO();
	$query = "SELECT COUNT(1) `cnt` FROM `information_schema`.`STATISTICS` WHERE `TABLE_SCHEMA` = ".$db->q($base)." AND `TABLE_NAME` = ".$db->q($table)." AND `INDEX_NAME` = ".$db->q($index);
	$db->setQuery($query);

	return $db->loadResult();
}
